/*
 * IR to Switch Closure
 * This code was written by Rich Simpson and edited by Elyse Barnes
 * Date: March 2023
 * License: This code is public domain
 *
 * This project allows a person to make a switch-closure happen using a
 * remote control:
 * 
 * IR Remote -> IR Signal -------> IR Receiver Diode -> Relay -> Switch Closure
 *
 */

// Library for IR code
// Sparkfun product page: https://www.sparkfun.com/products/10266
// Library page: https://github.com/shirriff/Arduino-IRremote/
// I used version 3.9.0 of the IR Remote library
#include <IRremote.hpp>

// Library for I2C (Qwiic) interface 
// Sparkfun product page: https://www.sparkfun.com/products/15123
// Library page: https://www.arduino.cc/reference/en/language/functions/communication/wire/
#include <Wire.h>

// Library for using the SparkFun Qwiic Relay 
// Sparkfun product page: https://www.sparkfun.com/products/15093
// Library page: https://github.com/sparkfun/SparkFun_Qwiic_Relay_Arduino_Library
// I used version 1.2.0
#include "SparkFun_Qwiic_Relay.h"

// Declare the relay object
#define RELAY_ADDR 0x18 // Alternate address 0x19
Qwiic_Relay relay(RELAY_ADDR); 
// Declare the pin that gets input from the relay
int IR_RECV_PIN = 11;
// Declare the pin that receives input from the potentiometer
int potPin = A0; 

  
void setup() {
  // Turn on I2C/Qwiic support 
  Wire.begin(); 
  // Turn on serial output
  Serial.begin(115200);
  
  // Activate the relay
  if(!relay.begin())
    Serial.println("Check connections to Qwiic Relay.");
  else
    Serial.println("Ready to flip some switches.");
  // Activate the IR Receiver
  IrReceiver.begin(IR_RECV_PIN, ENABLE_LED_FEEDBACK);
}

void loop() {
  // Name the data received from the potentiometer 
  int potValue = analogRead(A0); 
  // map the potentiometer values to the amount of time we want the delay (in ms)
  int potMap = map(potValue,0,1023,0,30000); 

  // Did we get a signal?
  if (IrReceiver.decode()) {
      // Print out the signal for debugging
      Serial.println("Got one!");
      Serial.println(IrReceiver.decodedIRData.decodedRawData, HEX);
      Serial.println(potMap);
      IrReceiver.printIRResultShort(&Serial); // optional use new print version 
      // Turn on the relay for as long as declared by the potentiometer (turning the device on)
      relay.turnRelayOn(); 
      delay(potMap); 
      // Turn off the relay and then wait 1 second
      relay.turnRelayOff(); 
      delay(1000);
      // Re-activate the IR receiver diode
      IrReceiver.resume(); 
  }
}
